@@ -199,7 +199,7 @@ void History::Private::doIt(OperationType type)
     Q_ASSERT(!stack().isEmpty());
     mEntryInProgress = stack().pop();
 
-    connect(mEntryInProgress.data(), SIGNAL(finished(Akonadi::IncidenceChanger::ResultCode,QString)), SLOT(handleFinished(Akonadi::IncidenceChanger::ResultCode,QString)),
+    connect(mEntryInProgress.data(), &Entry::finished, this, &Private::handleFinished,
             Qt::UniqueConnection);
     mEntryInProgress->doIt(type);
 }
