@@ -124,36 +124,8 @@ static void emitDeleteFinished(IncidenceChanger *changer,
 }
 }
 
-class ConflictPreventerPrivate;
-class ConflictPreventer
-{
-    friend class ConflictPreventerPrivate;
-public:
-    static ConflictPreventer *self();
-
-    // To avoid conflicts when the two modifications came from within the same application
-    QHash<Akonadi::Item::Id, int> mLatestRevisionByItemId;
-private:
-    ConflictPreventer()
-    {
-    }
-    ~ConflictPreventer()
-    {
-    }
-};
-
-class ConflictPreventerPrivate
-{
-public:
-    ConflictPreventer instance;
-};
-
-Q_GLOBAL_STATIC(ConflictPreventerPrivate, sConflictPreventerPrivate)
-
-ConflictPreventer *ConflictPreventer::self()
-{
-    return &sConflictPreventerPrivate->instance;
-}
+typedef QHash<Akonadi::Item::Id, int> IdToRevisionHash;
+Q_GLOBAL_STATIC(IdToRevisionHash, s_latestRevisionByItemId)
 
 IncidenceChanger::Private::Private(bool enableHistory, ITIPHandlerComponentFactory *factory, IncidenceChanger *qq)
     : q(qq)
@@ -311,8 +283,8 @@ void IncidenceChanger::Private::handleCreateJobResult(KJob *job)
         change->newItem = item;
 
         if (change->useGroupwareCommunication) {
-            connect(change.data(), SIGNAL(dialogClosedAfterChange(int,ITIPHandlerHelper::SendResult)),
-                    SLOT(handleCreateJobResult2(int,ITIPHandlerHelper::SendResult)));
+            connect(change.data(), &Change::dialogClosedAfterChange,
+                    this, &Private::handleCreateJobResult2);
             handleInvitationsAfterChange(change);
         } else {
             handleCreateJobResult2(change->id, ITIPHandlerHelper::ResultSuccess);
@@ -400,8 +372,8 @@ void IncidenceChanger::Private::handleDeleteJobResult(KJob *job)
         }
 
         if (change->useGroupwareCommunication) {
-            connect(change.data(), SIGNAL(dialogClosedAfterChange(int,ITIPHandlerHelper::SendResult)),
-                    SLOT(handleDeleteJobResult2(int,ITIPHandlerHelper::SendResult)));
+            connect(change.data(), &Change::dialogClosedAfterChange,
+                    this, &Private::handleDeleteJobResult2);
             handleInvitationsAfterChange(change);
         } else {
             handleDeleteJobResult2(change->id, ITIPHandlerHelper::ResultSuccess);
@@ -469,7 +441,8 @@ void IncidenceChanger::Private::handleModifyJobResult(KJob *job)
                                   Q_ARG(Akonadi::Item::Id, item.id()));
 
     } else { // success
-        ConflictPreventer::self()->mLatestRevisionByItemId[item.id()] = item.revision();
+
+        (*(s_latestRevisionByItemId()))[item.id()] = item.revision();
         change->newItem = item;
         if (change->recordToHistory && !change->originalItems.isEmpty()) {
             Q_ASSERT(change->originalItems.count() == 1);
@@ -478,8 +451,8 @@ void IncidenceChanger::Private::handleModifyJobResult(KJob *job)
         }
 
         if (change->useGroupwareCommunication) {
-            connect(change.data(), SIGNAL(dialogClosedAfterChange(int,ITIPHandlerHelper::SendResult)),
-                    SLOT(handleModifyJobResult2(int,ITIPHandlerHelper::SendResult)));
+            connect(change.data(), &Change::dialogClosedAfterChange,
+                    this, &Private::handleModifyJobResult2);
             handleInvitationsAfterChange(change);
         } else {
             handleModifyJobResult2(change->id, ITIPHandlerHelper::ResultSuccess);
@@ -533,8 +506,8 @@ void IncidenceChanger::Private::handleInvitationsBeforeChange(const Change::Ptr
                 handler->setDefaultAction(actionFromStatus(mInvitationStatusByAtomicOperation.value(change->atomicOperationId)));
             }
 
-            connect(handler, SIGNAL(finished(Akonadi::ITIPHandlerHelper::SendResult,QString)),
-                    change.data(), SLOT(emitUserDialogClosedBeforeChange(Akonadi::ITIPHandlerHelper::SendResult)));
+            connect(handler, &ITIPHandlerHelper::finished,
+                    change.data(), &Change::emitUserDialogClosedBeforeChange);
 
             foreach (const Akonadi::Item &item, change->originalItems) {
                 Q_ASSERT(item.hasPayload<KCalCore::Incidence::Ptr>());
@@ -620,8 +593,8 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
 {
     if (change->useGroupwareCommunication) {
         ITIPHandlerHelper *handler = new ITIPHandlerHelper(mFactory, change->parentWidget);
-        connect(handler, SIGNAL(finished(Akonadi::ITIPHandlerHelper::SendResult,QString)),
-                change.data(), SLOT(emitUserDialogClosedAfterChange(Akonadi::ITIPHandlerHelper::SendResult)));
+        connect(handler, &ITIPHandlerHelper::finished,
+                change.data(), &Change::emitUserDialogClosedAfterChange);
         handler->setParent(this);
 
         const bool alwaysSend = m_invitationPolicy == InvitationPolicySend;
@@ -884,8 +857,8 @@ int IncidenceChanger::deleteIncidences(const Item::List &items, QWidget *parent)
     d->mChangeById.insert(changeId, change);
 
     if (d->mGroupwareCommunication) {
-        connect(change.data(), SIGNAL(dialogClosedBeforeChange(int,ITIPHandlerHelper::SendResult)),
-                d, SLOT(deleteIncidences2(int,ITIPHandlerHelper::SendResult)));
+        connect(change.data(), &Change::dialogClosedBeforeChange,
+                d, &Private::deleteIncidences2);
         d->handleInvitationsBeforeChange(change);
     } else {
         d->deleteIncidences2(changeId, ITIPHandlerHelper::ResultSuccess);
@@ -918,8 +891,8 @@ void IncidenceChanger::Private::deleteIncidences2(int changeId, ITIPHandlerHelpe
     }
 
     // QueuedConnection because of possible sync exec calls.
-    connect(deleteJob, SIGNAL(result(KJob*)),
-            SLOT(handleDeleteJobResult(KJob*)), Qt::QueuedConnection);
+    connect(deleteJob, &KJob::result,
+            this, &Private::handleDeleteJobResult, Qt::QueuedConnection);
 }
 
 int IncidenceChanger::modifyIncidence(const Item &changedItem,
@@ -1011,8 +984,8 @@ void IncidenceChanger::Private::performModification(const Change::Ptr &change)
         return;
     }
     if (mGroupwareCommunication) {
-        connect(change.data(), SIGNAL(dialogClosedBeforeChange(int,ITIPHandlerHelper::SendResult)),
-                SLOT(performModification2(int,ITIPHandlerHelper::SendResult)));
+        connect(change.data(), &Change::dialogClosedBeforeChange,
+                this, &Private::performModification2);
         handleInvitationsBeforeChange(change);
     } else {
         performModification2(change->id,  ITIPHandlerHelper::ResultSuccess);
@@ -1036,15 +1009,14 @@ void IncidenceChanger::Private::performModification2(int changeId, ITIPHandlerHe
     const uint atomicOperationId = change->atomicOperationId;
     const bool hasAtomicOperationId = atomicOperationId != 0;
 
-    QHash<Akonadi::Item::Id, int> &latestRevisionByItemId =
-        ConflictPreventer::self()->mLatestRevisionByItemId;
+    QHash<Akonadi::Item::Id, int> &latestRevisionByItemId = *(s_latestRevisionByItemId());
     if (latestRevisionByItemId.contains(id) &&
             latestRevisionByItemId[id] > newItem.revision()) {
         /* When a ItemModifyJob ends, the application can still modify the old items if the user
          * is quick because the ETM wasn't updated yet, and we'll get a STORE error, because
          * we are not modifying the latest revision.
          *
-         * When a job ends, we keep the new revision in mLatestRevisionByItemId
+         * When a job ends, we keep the new revision in s_latestRevisionByItemId
          * so we can update the item's revision
          */
         newItem.setRevision(latestRevisionByItemId[id]);
@@ -1098,8 +1070,8 @@ void IncidenceChanger::Private::performModification2(int changeId, ITIPHandlerHe
 
         mModificationsInProgress[newItem.id()] = change;
         // QueuedConnection because of possible sync exec calls.
-        connect(modifyJob, SIGNAL(result(KJob*)),
-                SLOT(handleModifyJobResult(KJob*)), Qt::QueuedConnection);
+        connect(modifyJob, &KJob::result,
+                this, &Private::handleModifyJobResult, Qt::QueuedConnection);
     }
 }
 
@@ -1445,8 +1417,8 @@ Akonadi::TransactionSequence *AtomicOperation::transaction()
 
         m_incidenceChangerPrivate->mAtomicOperationByTransaction.insert(m_transaction, m_id);
 
-        QObject::connect(m_transaction, SIGNAL(result(KJob*)),
-                         m_incidenceChangerPrivate, SLOT(handleTransactionJobResult(KJob*)));
+        QObject::connect(m_transaction, &KJob::result,
+                         m_incidenceChangerPrivate, &IncidenceChanger::Private::handleTransactionJobResult);
     }
 
     return m_transaction;
