@@ -252,13 +252,14 @@ public:
     Akonadi::TransactionSequence *transaction();
 
 private:
+    Q_DISABLE_COPY(AtomicOperation)
     QVector<Change::Ptr> m_changes;
     bool m_wasRolledback;
     Akonadi::TransactionSequence *m_transaction; // constructed in first use
     IncidenceChanger::Private *m_incidenceChangerPrivate;
 };
 
-class IncidenceChanger::Private : public QObject
+class Q_DECL_HIDDEN IncidenceChanger::Private : public QObject
 {
     Q_OBJECT
 public:
