@@ -313,7 +313,7 @@ void Scheduler::acceptRequest(const IncidenceBase::Ptr &incidenceBase,
                    "<item>you no longer have access to the calendar containing the invitation</item>"
                    "</list></para>"
                    "<para>This is not a problem, but we thought you should know.</para>"),
-            i18nc("@title", "Cannot find invitation to be updated"), QLatin1String("AcceptCantFindIncidence"));
+            i18nc("@title", "Cannot find invitation to be updated"), QStringLiteral("AcceptCantFindIncidence"));
     }
     qCDebug(AKONADICALENDAR_LOG) << "Storing new incidence with scheduling uid=" << schedulingUid << " and uid=" << incidence->uid();
 
@@ -662,10 +662,10 @@ void Scheduler::handleDeleteFinished(bool success, const QString &errorMessage)
 
 void Scheduler::connectCalendar(const Akonadi::CalendarBase::Ptr &calendar)
 {
-    connect(calendar.data(), SIGNAL(createFinished(bool,QString)),
-            SLOT(handleCreateFinished(bool,QString)), Qt::UniqueConnection);
-    connect(calendar.data(), SIGNAL(modifyFinished(bool,QString)),
-            SLOT(handleModifyFinished(bool,QString)), Qt::UniqueConnection);
-    connect(calendar.data(), SIGNAL(deleteFinished(bool,QString)),
-            SLOT(handleDeleteFinished(bool,QString)), Qt::UniqueConnection);
+    connect(calendar.data(), &CalendarBase::createFinished,
+            this, &Scheduler::handleCreateFinished, Qt::UniqueConnection);
+    connect(calendar.data(), &CalendarBase::modifyFinished,
+            this, &Scheduler::handleModifyFinished, Qt::UniqueConnection);
+    connect(calendar.data(), &CalendarBase::deleteFinished,
+            this, &Scheduler::handleDeleteFinished, Qt::UniqueConnection);
 }
