@@ -34,7 +34,7 @@
 
 using namespace Akonadi;
 
-class StandardCalendarActionManager::Private
+class Q_DECL_HIDDEN StandardCalendarActionManager::Private
 {
 public:
     Private(KActionCollection *actionCollection, QWidget *parentWidget, StandardCalendarActionManager *parent)
@@ -45,8 +45,8 @@ public:
           mParent(parent)
     {
         mGenericManager = new StandardActionManager(actionCollection, parentWidget);
-        mParent->connect(mGenericManager, SIGNAL(actionStateUpdated()),
-                         mParent, SIGNAL(actionStateUpdated()));
+        mParent->connect(mGenericManager, &StandardActionManager::actionStateUpdated,
+                         mParent, &StandardCalendarActionManager::actionStateUpdated);
         mGenericManager->setMimeTypeFilter(QStringList() << QStringLiteral("text/calendar"));
         mGenericManager->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));
     }
@@ -76,10 +76,10 @@ public:
                 StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageTitle,
                 i18n("Calendar folder creation failed"));
             mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setProperty("ContentMimeTypes", QStringList() <<
-                    QLatin1String("inode/directory") <<
-                    QLatin1String("application/x-vnd.akonadi.calendar.todo") <<
-                    QLatin1String("application/x-vnd.akonadi.calendar.event") <<
-                    QLatin1String("application/x-vnd.akonadi.calendar.journal"));
+                    QStringLiteral("inode/directory") <<
+                    QStringLiteral("application/x-vnd.akonadi.calendar.todo") <<
+                    QStringLiteral("application/x-vnd.akonadi.calendar.event") <<
+                    QStringLiteral("application/x-vnd.akonadi.calendar.journal"));
 
             break;
         case  Akonadi::StandardActionManager::CopyCollections:
